<template>
  <basic-container>
    <v-chart id="chart" :auto-resize="true" :options="chartOptions"></v-chart>
    <div style="display: inline-block;float: right;margin-bottom: 10px;margin-right: 60px">
      <el-button size="small" type="danger" plain @click="delHandler">删除</el-button>
    </div>
  </basic-container>
</template>

<script>
import 'echarts'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/legend'
import { deleteChartId } from "@/api/statistic/chart"

export default {
  name: "ColumnarChart",
  props: {
    columnarData: {
      type: Array,
      default: []
    },
    chartName: {
      type: String,
      default: ""
    },
    btmname: {
      type: String
    }
  },
  watch: {
    columnarData: {
      immediate: true,
      handler(newval, oldval) {
        if (newval && newval.length > 0) {
          let seriesData = newval.map((data, index) => {
            let name = index === 0 ? "总量" : "新增";
            return {
              name: name,
              type: 'bar',
              data: data,
              barWidth: '40%',
              label: {
                show: true,
                position: 'top',
                // formatter: function (params) {
                //   if (params.value !== 0) {
                //     return params.value;
                //   } else {
                //     return '';
                //   }
                // }
              },
            };
          });
          this.chartOptions.series = seriesData;
        }
      }
    },
    chartName: {
      handler(newval, oldval) {
        if (newval) {
          this.chartOptions.title.text = newval + "数据统计"
        }
      },
      immediate: true,
      deep: true
    }
  },
  data() {
    return {
      chartOptions: {
        color: ['#84C9E5', '#F68686'],
        title: {
          text: "",
        },
        grid: {
          left: "3%",
          right: "4%",
          bottom: "3%",
          containLabel: true,
        },
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow",
          },
        },
        legend: {
          data: ["总量", "新增"],
          left: "center",
          textStyle: {
            fontSize: 14 // 调整字体大小
          }
        },
        xAxis: {
          type: "category",
          data: [
            "一月",
            "二月",
            "三月",
            "四月",
            "五月",
            "六月",
            "七月",
            "八月",
            "九月",
            "十月",
            "十一月",
            "十二月",
          ],
        },
        yAxis: {
          type: "value",
        },
        series: [],
      },
    };
  },
  created() {
  },
  methods: {
    delHandler() {
      deleteChartId({ btmname: this.btmname, chartId: '2' }).then(res => {
        this.$message.success(this.chartName+'柱状图，删除成功！')
        this.$emit('refresh');
      }).catch(error => {
        this.$message.error(error)
      })
    }
  }
};
</script>

<style scoped lang="scss">
#chart {
  width: 100%;
  height: 560px;
}
</style>
